@@ -13,13 +13,32 @@ num2pal <- function(x, n = 5,
 					   legend.format=list(scientific=FALSE)) {
 	breaks.specified <- !is.null(breaks)
 	is.cont <- (style=="cont" || style=="order")
+	
 	if (is.cont) {
-		style <- ifelse(style=="order", "quantile", "equal")
+		style <- ifelse(style=="order", "quantile", "fixed")
+
+		if (style=="fixed") {
+			custom_breaks <- breaks
+			
+			if (!is.null(custom_breaks)) {
+				n <- length(breaks) - 1
+			} else {
+				breaks <- range(x, na.rm = TRUE)
+			}
+			breaks <- cont_breaks(breaks, n=101)
+		}
+		
 		if (is.null(legend.labels)) {
 			ncont <- n
 		} else {
-			ncont <- length(legend.labels)
+			if (!is.null(custom_breaks) && length(legend.labels) != n+1) {
+				warning("legend.labels not the same length as breaks", call.=FALSE)
+				legend.labels <- NULL
+			} else {
+				ncont <- length(legend.labels)	
+			}
 		}
+		
 		q <- num2breaks(x=x, n=101, style=style, breaks=breaks, approx=TRUE, interval.closure=interval.closure)
 		n <- length(q$brks) - 1
 	} else {
@@ -129,8 +148,12 @@ num2pal <- function(x, n = 5,
 			b <- breaks[id]
 			nbrks_cont <- length(b)
 		} else {
-			b <- pretty(breaks, n=ncont)
-			b <- b[b>=breaks[1] & b<=breaks[length(breaks)]]
+			if (!is.null(custom_breaks)) {
+				b <- custom_breaks
+			} else {
+				b <- pretty(breaks, n=ncont)
+				b <- b[b>=breaks[1] & b<=breaks[length(breaks)]]
+			}
 			nbrks_cont <- length(b)
 			id <- as.integer(cut(b, breaks=breaks, include.lowest = TRUE))
 		}
@@ -147,6 +170,9 @@ num2pal <- function(x, n = 5,
 		# temporarily stack gradient colors
 		legend.palette <- sapply(legend.palette, paste, collapse="-")
 		
+		# create legend values
+		legend.values <- b
+		
 		# create legend labels for continuous cases
 		if (is.null(legend.labels)) {
 			legend.labels <- do.call("fancy_breaks", c(list(vec=b, intervals=FALSE, interval.closure=int.closure), legend.format)) 	
@@ -158,6 +184,9 @@ num2pal <- function(x, n = 5,
 		}		
 		attr(legend.palette, "style") <- style
 	} else {
+		# create legend values
+		legend.values <- breaks[-nbrks]
+		
 		# create legend labels for discrete cases
 		if (is.null(legend.labels)) {
 			legend.labels <- do.call("fancy_breaks", c(list(vec=breaks, intervals=TRUE, interval.closure=int.closure), legend.format)) 
@@ -168,5 +197,17 @@ num2pal <- function(x, n = 5,
 		
 		if (showNA) legend.labels <- c(legend.labels, legend.NA.text)
 	}
-	list(cols=cols, legend.labels=legend.labels, legend.palette=legend.palette, breaks=breaks, breaks.palette=breaks.palette, legend.neutral.col = legend.neutral.col)
+	list(cols=cols, legend.labels=legend.labels, legend.values=legend.values, legend.palette=legend.palette, breaks=breaks, breaks.palette=breaks.palette, legend.neutral.col = legend.neutral.col)
 }
+
+
+cont_breaks <- function(breaks, n=101) {
+	x <- round(seq(1, 101, length.out=length(breaks)))
+	
+	
+	unlist(lapply(1L:(length(breaks)-1L), function(i) {
+		y <- seq(breaks[i], breaks[i+1], length.out=x[i+1]-x[i]+1)	
+		if (i!=1) y[-1] else y
+	}))
+}
+
