@@ -4,8 +4,8 @@ split_g <- function(g, n) {
 	# vector-argments: small multiples can take lists (lnames)
 	# list-arguments: small multiples can take nested lists (nlnames)
 	vnames <- c("alpha", "convert2density", "n", "style", "auto.palette.mapping", "max.categories", "colorNA", "textNA", "showNA", "interval.closure", "shapeNA", "shape.textNA","shapes.n", "shapes.style", "shapes.breaks", "shapes.interval.closure", "perceptual", "scale", "root", "size.lowerbound", "print.tiny")
-	lnames <- c("palette", "breaks", "labels", "contrast", "size.lim", "size.lim", "sizes.legend", "sizes.legend.labels", "lwd.legend", "lwd.legend.labels", "line.lwd.legend.labels", "shapes")
-	nlnames <- c("legend.format")
+	lnames <- c("palette", "breaks", "labels", "contrast", "size.lim", "size.lim", "sizes.legend", "sizes.legend.labels", "sizes.legend.values", "lwd.legend", "lwd.legend.labels", "lwd.legend.values", "line.lwd.legend.labels", "line.lwd.legend.values", "shapes")
+	nlnames <- c("legend.format", "popup.format")
 	lapply(1:n, function(i) {
 		g[vnames] <- lapply(g[vnames], function(x) {
 			if (length(x)==n) x[i] else x[1]
