@@ -7,10 +7,12 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 	gt <- gp$tm_layout
 	gp$tm_layout <- NULL
 	
-	lf <- leaflet()
+	lf <- leaflet(options = leaflet::leafletOptions(crs=gt$projection))
 	basemaps <- gt$basemaps
 	basemaps.alpha <- gt$basemaps.alpha
 	
+	pOptions <- leaflet::popupOptions(minWidth = 200, maxWidth = 200)
+	
 	if (is.null(names(basemaps))) names(basemaps) <- sapply(basemaps, FUN = function(bm) {
 		if (substr(bm, 1, 4) == "http") {
 			x <- strsplit(bm, "/", fixed=TRUE)[[1]]
@@ -78,7 +80,7 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 
 	bbx <- attr(shps[[1]], "bbox")
 	
-	warns <- c(symbol=FALSE, text=FALSE, raster=FALSE) # to prevent a warning for each shape
+	warns <- c(symbol=FALSE, text=FALSE, raster=FALSE, symbol_legend=FALSE, linelwd_legend=FALSE) # to prevent a warning for each shape
 	
 	group_selection <- mapply(function(shp, gpl, shp_name) {
 		bbx <- attr(shp, "bbox")
@@ -101,7 +103,7 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 			fres <- split_alpha_channel(gpl$fill, alpha=alpha)
 			fcol <- fres$col
 			fopacity <- fres$opacity
-
+			
 			if (!is.null(gpl$fill)) {
 				popups <- get_popups(gpl, type="fill")
 			} else {
@@ -110,7 +112,7 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 			stroke <- gpl$lwd>0 && !is.na(bcol) && bopacity!=0
 
 		
-			lf <- lf %>% addPolygons(data=shp, stroke=stroke, weight=gpl$lwd, color=bcol, fillColor = fcol, opacity=bopacity, fillOpacity = fopacity, popup = popups, options = pathOptions(clickable=!is.null(popups)), group=shp_name, layerId = id)
+			lf <- lf %>% addPolygons(data=shp, stroke=stroke, weight=gpl$lwd, color=bcol, fillColor = fcol, opacity=bopacity, fillOpacity = fopacity, popup = popups, options = pathOptions(clickable=!is.null(popups)), group=shp_name, layerId = id, popupOptions = pOptions)
 
 
 			if (!is.na(gpl$xfill[1])) {
@@ -130,13 +132,19 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 			popups <- get_popups(gpl, type="line")
 			dashArray <- lty2dashArray(gpl$line.lty)
 			
-			lf <- lf %>% addPolylines(data=shp, stroke=TRUE, weight=gpl$line.lwd, color=lcol, opacity = lopacity, popup = popups, options = pathOptions(clickable=!is.null(popups)), dashArray=dashArray, group=shp_name, layerId = id)
+			lf <- lf %>% addPolylines(data=shp, stroke=TRUE, weight=gpl$line.lwd, color=lcol, opacity = lopacity, popup = popups, options = pathOptions(clickable=!is.null(popups)), dashArray=dashArray, group=shp_name, layerId = id, popupOptions = pOptions)
 
 			
 			if (!is.na(gpl$xline[1])) {
 				if (gpl$line.col.legend.show) lf <- lf %>% add_legend(gpl, gt, aes="line.col", alpha=alpha)
 			}
 			
+			if (!is.na(gpl$xlinelwd[1]) && gpl$line.lwd.legend.show) {
+				warns["linelwd_legend"] <- TRUE
+				assign("warns", warns, envir = e)
+			}
+			
+			
 			assign("lf", lf, envir = e)
 			assign("id", id+1, envir = e)
 			
@@ -203,7 +211,7 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 			}
 			
 			
-			rad <- symbol.size2 * upl
+			rad <- unname(symbol.size2 * upl)
 			
 			fixed <- ifelse(gpl$symbol.misc$symbol.are.dots, gt$dot.size.fixed, gt$symbol.size.fixed)
 			are.icons <- gpl$symbol.misc$symbol.are.icons
@@ -226,14 +234,14 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 				lf <- lf %>% addMarkers(lng = co2[,1], lat=co2[,2], popup=popups2, group=shp_name, icon=icons, layerId = id)
 			} else {
 				if (!all(symbol.shape2 %in% c(1, 16, 19, 20, 21))) {
-					warns["symbol"]
+					warns["symbol"] <- TRUE
 					assign("warns", warns, envir = e)
 				}
 
 				if (fixed) {
-					lf <- lf %>% addCircleMarkers(lng=co2[,1], lat=co2[,2], fill = any(!is.na(fcol2)), fillColor = fcol2, fillOpacity=fopacity, color = bcol, stroke = !is.na(bcol) && bopacity!=0, radius = 20*symbol.size2, weight = 1, popup=popups2, group=shp_name, layerId = id)
+					lf <- lf %>% addCircleMarkers(lng=co2[,1], lat=co2[,2], fill = any(!is.na(fcol2)), fillColor = fcol2, fillOpacity=fopacity, color = bcol, stroke = !is.na(bcol) && bopacity!=0, radius = 20*symbol.size2, weight = 1, popup=popups2, group=shp_name, layerId = id, popupOptions = pOptions)
 				} else {
-					lf <- lf %>% addCircles(lng=co2[,1], lat=co2[,2], fill = any(!is.na(fcol2)), fillColor = fcol2, fillOpacity=fopacity, color = bcol, stroke = !is.na(bcol) && bopacity!=0, radius=rad, weight =1, popup=popups2, group=shp_name, layerId = id)
+					lf <- lf %>% addCircles(lng=co2[,1], lat=co2[,2], fill = any(!is.na(fcol2)), fillColor = fcol2, fillOpacity=fopacity, color = bcol, stroke = !is.na(bcol) && bopacity!=0, radius=rad, weight =1, popup=popups2, group=shp_name, layerId = id, popupOptions = pOptions)
 				}
 			}
 				
@@ -243,6 +251,12 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 				if (gpl$symbol.col.legend.show) lf <- lf %>% add_legend(gpl, gt, aes="symbol.col", alpha=alpha)
 			}
 			
+			if (!is.na(gpl$xsize[1]) && gpl$symbol.size.legend.show) {
+				warns["symbol_legend"] <- TRUE
+				assign("warns", warns, envir = e)
+			}
+
+			
 
 			assign("lf", lf, envir = e)
 			assign("id", id+1, envir = e)
@@ -250,11 +264,67 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 			
 		}
 		plot_tm_text <- function() {
-			if (is.null(gpl$symbol.misc) || !gpl$symbol.misc$symbol.are.markers) {
-				warns["text"] <- TRUE
-				assign("warns", warns, envir = e)
+# 			if (is.null(gpl$symbol.misc) || !gpl$symbol.misc$symbol.are.markers) {
+# 				warns["text"] <- TRUE
+# 				assign("warns", warns, envir = e)
+# 			}
+#  			FALSE
+			npol <- nrow(co)
+			text <- gpl$text
+			col <- unname(gpl$text.color)
+			size <- unname(gpl$text.size)
+			
+			opacity <- gpl$text.alpha
+			
+			
+			co[, 1] <- co[, 1] + gpl$text.xmod * bpl
+			co[, 2] <- co[, 2] + gpl$text.ymod * bpl
+			
+			# return NULL is no symbols are selected (see tm_facets example)
+			if (!any(gpl$text_sel)) return(FALSE)
+			
+			if (!all(gpl$text_sel)) {
+				co <- co[gpl$text_sel, , drop=FALSE]
+				text <- text[gpl$text_sel]
+				col <- col[gpl$text_sel]
+				size <- size[gpl$text_sel]
 			}
- 			FALSE
+			
+			sizeChar <- paste(round(size * 12), "px", sep="")
+			colsize <- paste(col, sizeChar, sep="_^_")
+			
+			just <- switch(gpl$text.just[1],
+						   left="right", 
+						   right="left",
+						   "bottom")
+			
+				
+			cs_set <- unique(colsize)
+			
+			if (length(cs_set)==1) {
+				lf <- lf %>% addLabelOnlyMarkers(lng = co[,1], lat = co[,2], label=text,
+												 labelOptions = labelOptions(noHide = TRUE, textOnly = TRUE, direction = just, 
+												 							opacity=opacity,
+												 							textsize=sizeChar[1],
+												 							style=list(color=col[1])))
+			} else {
+				for (i in 1:length(text)) {
+					lf <- lf %>% addLabelOnlyMarkers(lng = co[i,1], lat = co[i,2], label=text[i],
+													 labelOptions = labelOptions(noHide = TRUE, textOnly = TRUE, direction = just, 
+													 							opacity=opacity,
+													 							textsize=sizeChar[i],
+													 							style=list(color=col[i])))	
+				}
+			}
+			
+			if (!is.na(gpl$xtcol[1])) {
+				if (gpl$text.col.legend.show) lf <- lf %>% add_legend(gpl, gt, aes="text.col", alpha=alpha)
+			}
+			
+			assign("lf", lf, envir = e)
+			assign("id", id+1, envir = e)
+			
+			TRUE
 		}
 		plot_tm_raster <- function() {
 			if (gpl$raster.misc$is.OSM) {
@@ -288,7 +358,11 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 			TRUE
 		}
 		plot_tm_grid <- function() {
-			FALSE
+			lf <- lf %>% addGraticule()
+			
+			assign("lf", lf, envir = e)
+			assign("id", id+1, envir = e)
+			TRUE
 		}
 		
 		e2 <- environment()
@@ -299,10 +373,11 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 	}, shps, gp, gt$shp_name, SIMPLIFY = TRUE)
 	
 	if (showWarns) {
-		if (warns["symbol"]) warning("Symbol shapes other than circles are not supported in view mode.", call.=FALSE)
-		if (warns["text"]) warning("Text labels not supported in view mode.", call.=FALSE)
+		if (warns["symbol"]) message("Symbol shapes other than circles or icons are not supported in view mode.")
+		if (warns["symbol_legend"]) message("Legend for symbol sizes not available in view mode.")
+		if (warns["linelwd_legend"]) message("Legend for line widths not available in view mode.")
 		if (identical(unname(warns["raster"]), TRUE)) {
-			warning("Raster data contains OpenStreetMapData (read with read_osm) from provider that is not known from http://leaflet-extras.github.io/leaflet-providers/preview/index.html", call.=FALSE)	
+			message("Raster data contains OpenStreetMapData (read with read_osm) from provider that is not known from http://leaflet-extras.github.io/leaflet-providers/preview/index.html")	
 		} else if (!(identical(unname(warns["raster"]), FALSE))) {
 			message("Raster data contains OpenStreetMapData (read with read_osm). Therefore, the basemap has been set to \"", warns["raster"], "\"")
 		}
@@ -326,16 +401,11 @@ view_tmap <- function(gp, shps=NULL, leaflet_id=1, showWarns=TRUE) {
 	
 	lf <- lf %>% addLayersControl(baseGroups=names(basemaps), overlayGroups = groups, options = layersControlOptions(autoZIndex = TRUE), position=control.position)  
 
-	# if (gt$scale.show) {
-	# 	leaflet_version <- packageVersion("leaflet")
-	# 	if (leaflet_version > "1.0.2") {
-	# 		u <- gt$shape.units_args$unit
-	# 		metric <- (u %in% c("m", "km", "metric"))
-	# 		lf <- lf %>% addScaleBar(position = gt$scale.position, options = scaleBarOptions(maxWidth=gt$scale.width, metric=metric, imperial = !metric))
-	# 	} else {
-	# 		message("Scale bar support in view mode need leaflet >= 1.02; installed version: ", leaflet_version)
-	# 	}
-	# }
+	if (gt$scale.show) {
+		u <- gt$shape.units_args$target
+		metric <- (u %in% c("m", "km", "metric"))
+	 	lf <- lf %>% addScaleBar(position = gt$scale.position, options = scaleBarOptions(maxWidth=gt$scale.width, metric=metric, imperial = !metric))
+	}
 	# print(leaflet_id)
 	# if (gt$title!="") {
 	# 	lf <- lf %>% onRender(paste("
@@ -377,12 +447,20 @@ set_bounds_view <- function(lf, gt, bbx) {
 	lf
 }
 
-format_popups <- function(id=NULL, titles, values) {
+format_popups <- function(id=NULL, titles, format, values) {
 	isnull <- sapply(values, is.null)
 	
 	titles <- titles[!isnull]
+	titles[names(titles)!=""] <- names(titles)[names(titles)!=""]
+	
 	values <- values[!isnull]
 	
+	islist <- is.list(format) && length(format)>0 && is.list(format[[1]])
+	if (!islist) {
+		format <- lapply(1:length(titles), function(i) format)
+	}
+	
+	
 	if (!is.null(id)) {
 		labels <- paste("<b>", htmlEscape(id), "</b>", sep="")
 	} else {
@@ -390,9 +468,9 @@ format_popups <- function(id=NULL, titles, values) {
 	}
 	
 	titles_format <- sapply(titles, htmlEscape)
-	values_format <- lapply(values, function(v) {
-		htmlEscape(if (is.numeric(v)) fancy_breaks(v) else v)
-	})
+	values_format <- mapply(function(v, f) {
+		htmlEscape(if (is.numeric(v)) do.call("fancy_breaks", c(list(vec=v, intervals=FALSE), f)) else v)
+	}, values, format, SIMPLIFY = FALSE)
 	
 	
 	labels2 <- mapply(function(l, v) {
@@ -446,20 +524,26 @@ get_aes_name <- function(type) {
 get_popups <- function(gpl, type) {
 	var_names <- paste(type, "names", sep=".")
 	var_vars <- paste(type, "popup.vars", sep=".")
+	var_format <- paste(type, "popup.format", sep=".")
 	
 	dt <- gpl$data
 
 	if (is.na(gpl[[var_vars]][1])) {
 		popups <- NULL
 	} else {
-		popups <- format_popups(dt[[gpl[[var_names]]]], gpl[[var_vars]], dt[, gpl[[var_vars]], drop=FALSE])
+		popups <- format_popups(dt[[gpl[[var_names]]]], gpl[[var_vars]], gpl[[var_format]], dt[, gpl[[var_vars]], drop=FALSE])
 	}
 	popups
 }
 
 add_legend <- function(map, gpl, gt, aes, alpha, list.only=FALSE) {
 	pal_name <- paste(aes, "legend.palette", sep=".")
+	val_name <- paste(aes, "legend.values", sep=".")
+	lab_name <- paste(aes, "legend.labels", sep=".")
+	
 	pal <- gpl[[pal_name]]
+	val <- gpl[[val_name]]
+	lab <- gpl[[lab_name]]
 	
 	if (nchar(pal[1])>10) {
 		style <- attr(pal, "style")
@@ -472,40 +556,59 @@ add_legend <- function(map, gpl, gt, aes, alpha, list.only=FALSE) {
 		if (incl.na) {
 			colNA <- unname(pal[length(pal)])
 			pal <- pal[-length(pal)]
-			val <- as.numeric(gsub(",", "", gpl$fill.legend.labels, fixed = TRUE))
+			textNA <- lab[length(lab)]
 		} else {
-			val <- as.numeric(gsub(",", "", gpl$fill.legend.labels, fixed = TRUE))
 			colNA <- NA
+			textNA <- NA
 		}
 	} else {
 		is.cont <- FALSE
+		if (length(pal) != length(val)) {
+			colNA <- pal[length(pal)]
+			textNA <- lab[length(pal)]
+			pal <- pal[-length(pal)]
+			lab <- lab[-length(lab)]
+		} else {
+			colNA <- NA
+			textNA <- NA
+		}
 	}
+
 	RGBA <- col2rgb(pal, alpha = TRUE)
 	col <- rgb(RGBA[1,], RGBA[2,], RGBA[3,], maxColorValue = 255)
 	opacity <- unname(RGBA[4,1]/255) * alpha
 	
+	if (!is.na(colNA)) {
+		RGBA_NA <- col2rgb(colNA, alpha = TRUE)
+		colNA <- rgb(RGBA_NA[1,], RGBA_NA[2,], RGBA_NA[3,], maxColorValue = 255)
+	}
+	
 	if (list.only) {
-		return(list(col=col, opacity=opacity))
+		if (!is.na(colNA)) col <- c(col, colNA)
+		return(list(col=pal, opacity=opacity))
 	}
 	
 	title_name <- paste(aes, "legend.title", sep=".")
-	lab_name <- paste(aes, "legend.labels", sep=".")
 	
 	title <- if (nonempty_text(gpl[[title_name]])) expr_to_char(gpl[[title_name]]) else NULL
 
 	legend.position <-gt$view.legend.position
 
 	if (is.cont) {
+		legvals <- if (!is.na(colNA)) c(val, NA) else val
+
 		if (style=="quantile") {
 			addLegend(map, position=legend.position,
-					  pal=colorQuantile(pal, val, na.color=colNA), values=val)
+					  pal=colorQuantile(col, val, na.color=colNA, alpha = FALSE), values=legvals, na.label = textNA, title=title, opacity=opacity)
 		} else {
 			addLegend(map, position=legend.position,
-					  pal=colorNumeric(pal, val, na.color=colNA), values=val)
+					  pal=colorNumeric(col, val, na.color=colNA, alpha = FALSE), values=legvals, na.label = textNA, title=title, opacity=opacity)
 		}
 	} else {
-		addLegend(map, position=legend.position,
-				  colors=col, labels = gpl[[lab_name]], opacity=opacity, title=title)
+		legvals <- if (!is.na(colNA)) factor(c(lab, NA), levels=lab) else factor(lab, levels=lab)
+		lab <- factor(lab, levels=lab)
+		addLegend(map, position=legend.position, 
+				  pal=colorFactor(col, domain=lab, na.color = colNA, ordered = TRUE, alpha = FALSE), values = legvals, na.label=textNA, title=title, opacity=opacity)
 	}
 }
 
@@ -521,13 +624,13 @@ working_internet <- function(url = "http://www.google.com") {
 }
 
 bbx_per_line <- function(bbx) {
-	max_lines <- par("din")[2]*10
+	max_lines <- 60 #par("din")[2]*10 #disabled because window height doesn't influence scaling
 	(bbx[2,2] - bbx[2,1]) / max_lines
 }
 
 units_per_line <- function(bbx) {
-	max_lines <- par("din")[2]*10
-	
+	max_lines <- 60 #par("din")[2]*10 #disabled because window height doesn't influence scaling
+
 	# calculate top-center to bottom-center
 	vdist <- tmaptools::approx_distances(bbx, projection = "longlat", target = "m")$vdist
 	vdist/max_lines
@@ -550,3 +653,11 @@ lty2dashArray <- function(lty) {
 		  collapse=",")
 }
 
+get_epsg_number <- function(proj) {
+	if (inherits(proj, "CRS")) proj <- attr(proj, "projargs")
+	
+	pat <- "^.*\\=epsg ?: ?(\\S*)(.*)$"
+	epsg <- as.numeric(sub(pat, "\\1", proj[grepl(pat, proj)]))
+	if (length(epsg)==0) NA else epsg
+}
+
